EntityData

Enum EntityData 

pub enum EntityData {
Show 43 variants Byte(i8), Int(i32), Long(i64), Float(f32), String(String), Boolean(bool), Component(Box<TextComponent>), OptionalComponent(Option<Box<TextComponent>>), ItemStack(ItemStack), Rotations(Rotations), BlockPos(BlockPos), OptionalBlockPos(Option<BlockPos>), Direction(Direction), OptionalLivingEntityRef(Option<Uuid>), BlockState(BlockStateId), OptionalBlockState(Option<BlockStateId>), Vector3(Vector3f), Quaternion(Quaternionf), Pose(EntityPose), SnifferState(SnifferState), ArmadilloState(ArmadilloState), Particle(ParticleData), Particles(ParticleList), VillagerData(VillagerData), OptionalUnsignedInt(Option<u32>), CatVariant(RegistryReference<CatVariant>), CatSoundVariant(RegistryReference<CatSoundVariant>), CowVariant(RegistryReference<CowVariant>), CowSoundVariant(RegistryReference<CowSoundVariant>), WolfVariant(RegistryReference<WolfVariant>), WolfSoundVariant(RegistryReference<WolfSoundVariant>), FrogVariant(RegistryReference<FrogVariant>), PigVariant(RegistryReference<PigVariant>), PigSoundVariant(RegistryReference<PigSoundVariant>), ChickenVariant(RegistryReference<ChickenVariant>), ChickenSoundVariant(RegistryReference<ChickenSoundVariant>), ZombieNautilusVariant(RegistryReference<ZombieNautilusVariant>), PaintingVariant(RegistryReference<PaintingVariant>), OptionalGlobalPos(Option<GlobalPos>), CopperGolemState(i32), WeatheringCopperState(i32), ResolvableProfile(ResolvableProfile), HumanoidArm(HumanoidArm),
}
Type-erased entity data for network encoding.

This enum holds the actual value to be sent over the network. Serialization happens through the EntityDataSerializerRegistry, not directly on this type. Use REGISTRY.entity_data_serializers.get_writer(id) to get the writer function for a specific serializer ID.

Variants



Byte(i8)



Int(i32)



Long(i64)



Float(f32)



String(String)



Boolean(bool)



Component(Box<TextComponent>)



OptionalComponent(Option<Box<TextComponent>>)



ItemStack(ItemStack)



Rotations(Rotations)



BlockPos(BlockPos)



OptionalBlockPos(Option<BlockPos>)



Direction(Direction)



OptionalLivingEntityRef(Option<Uuid>)



BlockState(BlockStateId)



OptionalBlockState(Option<BlockStateId>)



Vector3(Vector3f)



Quaternion(Quaternionf)



Pose(EntityPose)



SnifferState(SnifferState)



ArmadilloState(ArmadilloState)



Particle(ParticleData)



Particles(ParticleList)



VillagerData(VillagerData)



OptionalUnsignedInt(Option<u32>)



CatVariant(RegistryReference<CatVariant>)



CatSoundVariant(RegistryReference<CatSoundVariant>)



CowVariant(RegistryReference<CowVariant>)



CowSoundVariant(RegistryReference<CowSoundVariant>)



WolfVariant(RegistryReference<WolfVariant>)



WolfSoundVariant(RegistryReference<WolfSoundVariant>)



FrogVariant(RegistryReference<FrogVariant>)



PigVariant(RegistryReference<PigVariant>)



PigSoundVariant(RegistryReference<PigSoundVariant>)



ChickenVariant(RegistryReference<ChickenVariant>)



ChickenSoundVariant(RegistryReference<ChickenSoundVariant>)



ZombieNautilusVariant(RegistryReference<ZombieNautilusVariant>)



PaintingVariant(RegistryReference<PaintingVariant>)



OptionalGlobalPos(Option<GlobalPos>)



CopperGolemState(i32)



WeatheringCopperState(i32)



ResolvableProfile(ResolvableProfile)



HumanoidArm(HumanoidArm)